#!/bin/bash
# This can be used to copy search guard config files if it does not exist
# Needed if sgconfig directory is mounted on host filesystem resulting in empty directory on first mount

log() {
    echo "INFO : $1"
}

exitOnError() {
    echo "ERROR : $1"
    exit 1
}

copyFileNoOverwrite() {
    source=$1
    target=$2
    
    [[ ! -z ${source} ]] || exitOnError "Source file to copy not provided"
    [[ ! -z ${target} ]] || exitOnError "Target file for copy not provided"

    if ! [[ -f ${target} ]]; then
        log "Copying ${source} => ${target}"        
        cp -f ${source} ${target} || exitOnError "Copy of file from ${source} to ${target} failed. This can happen if parent of ${target} is mounted with wrong permissions, make sure user $USER (output of "id $USER" : $(id $USER))  has enough permissions to do this operation"
    fi
}

copyESConfigFiles() {
    local sourceDir=$1
    local targetDir=$2
    local fileList=$3

    if [[ -z "${sourceDir}" || -z "${targetDir}" || ! -d "${sourceDir}" || ! -d "${targetDir}" ]]; then
        return
    fi

    for file in ${fileList}; do
        copyFileNoOverwrite "${sourceDir}/${file}" "${targetDir}/${file}"
    done
}

SOURCE_DIR=/usr/share/elasticsearch/plugins/search-guard-6/sgconfig_copy
TARGET_DIR=/usr/share/elasticsearch/plugins/search-guard-6/sgconfig
FILE_LIST="sg_action_groups.yml sg_config.yml sg_internal_users.yml sg_roles.yml sg_roles_mapping.yml"

copyESConfigFiles "${SOURCE_DIR}" "${TARGET_DIR}" "${FILE_LIST}"